( IN-PACKAGE :TDWSOFT )
( USE-PACKAGE :OLI )

( DEFUN Tdw-get-sys-var-tdwsite ()
   ( LET (( L_tdw_site ( SD-SYS-GETENV "TDW_SITE" ))
          ( L_site_list '( "TDW" "LMT" "LWE" "LHG" "HHA" "LBC" ))
         )

         ( IF L_tdw_site
             ( PROGN
               ( SETF L_tdw_site ( SD-STRING-UPCASE L_tdw_site ))
               ( COND (( MEMBER L_tdw_site L_site_list :TEST #'STRING= )
                        L_tdw_site
                      )
                      (( STRING= L_tdw_site "KEM" )
                        "LVT"
                      )
                      ( T
                        "TDW"
                      )
               )
             )
             "TDW"
         )
   )
)

;-------------------------------------
; 3D-Macrodatei in das Annotation laden
; Parameter 1: Verzeichnis
; Parameter 2: Datei
;-------------------------------------

( DEFUN tdw-unitfile-universal-load ( P_path P_file )
  ( LET (( L_src_file ( FORMAT NIL "~A/src/~A.lsp" P_path P_file ))
         ( L_win_file ( FORMAT NIL "~A/win/~A.dll" P_path P_file ))
         ( L_x64_file ( FORMAT NIL "~A/x64/~A.dll" P_path P_file ))
         ( L_flag NIL )
        )

        ( UNLESS ( STRING= ( SD-SYS-GETENV "SDSRC" ) "SRC" )
            ( SETF L_flag T )
            ( IF (SD-OSDM64-P)
                ( IF ( SD-SEARCH-FILE L_x64_file )
                  ( LOAD L_x64_file )
                  ( SETF L_flag NIL )
                )
                ( IF ( SD-SEARCH-FILE L_win_file )
                  ( LOAD L_win_file )
                  ( SETF L_flag NIL )
                )
            )
        )

        ( UNLESS L_flag
           ( IF ( SD-SEARCH-FILE L_src_file )
              ( PROGN
                ( PRINT "Source-file will be loaded" )
                ( LOAD L_src_file )
              )
              ( PRINT ( FORMAT NIL "File ~A not exists" L_src_file ))
           )
        )
  )
)

;-------------------------------------
; 2D-Macrodatei in das Annotation laden
; Parameter 1: Verzeichnis
; Parameter 2: Datei
;-------------------------------------

( DEFUN Tdw-unitfile-anno-macro-load ( P_path P_file )
  ( LET (( L_src_file ( FORMAT NIL "~A/src/~A.mma" P_path P_file ))
         ( L_win_file ( FORMAT NIL "~A/win/~A.msm" P_path P_file ))
         ( L_flag NIL )
        )

        ( IF ( SD-SEARCH-FILE L_win_file )
          ( SD-EXECUTE-ANNOTATOR-COMMAND :CMD ( FORMAT NIL "LOAD_MACRO '~A'"  L_win_file  ))
          ( SETF L_flag NIL )
        )

        ( UNLESS L_flag
           ( IF ( SD-SEARCH-FILE L_src_file )
              ( PROGN
                ( PRINT "Source-file will be loaded" )
                ( SD-EXECUTE-ANNOTATOR-COMMAND :CMD ( FORMAT NIL "INPUT '~A'" L_src_file  ))
              )
              ( PRINT ( FORMAT NIL "File ~A not exists" L_src_file ))
           )
        )
  )
)

;-------------------------------------
; 2D-Macro-Conf-datei in das Annotation laden
; Parameter 1: Verzeichnis
; Parameter 2: Datei
;-------------------------------------

( DEFUN Tdw-unitfile-anno-conf-load ( P_path P_file )
  ( LET (( L_src_file ( FORMAT NIL "~A/~A.mma" P_path P_file ))
        )

        ( IF ( SD-SEARCH-FILE L_src_file )
           ( PROGN
             ( PRINT "Source-file will be loaded" )
             ( SD-EXECUTE-ANNOTATOR-COMMAND :CMD ( FORMAT NIL "INPUT '~A'" L_src_file  ))
           )
           ( PRINT ( FORMAT NIL "File ~A not exists" L_src_file ))
        )
  )
)

;-------------------------------------
; Anzeigetext aus Texttabelle lesen
; Parameter 1: Textnummer = Zeilennummer
; Parameter 2: Vorgabe
; Parameter 3: Sprachtabelle
;-------------------------------------

( DEFUN tdw-read-text ( P_text_row P_vorgabe P_table )
   ( LET (( L_lang ( SD-INQ-CURRENT-LANGUAGE ))
          ( L_message NIL )
         )

         ( UNLESS ( OR ( EQ L_lang :GERMAN ) ( EQ L_lang :ENGLISH ))
                   ( SETF L_lang :ENGLISH )
         )

         ( WHEN ( Sd-LOGICAL-TABLE-P P_table )

            ( SETF L_message ( SD-READ-LOGICAL-TABLE-CELL P_table
                                :PLIST ( LIST :INDEX ( FORMAT NIL "~A" P_text_row ))
                                :COLUMN L_lang )
            )
         )

         ( SETF L_message ( tdw-get-custom-message P_text_row P_vorgabe P_table ))

         ( UNLESS L_message ( SETF L_message P_vorgabe ))

         L_message

   )
)



;-------------------------------------
; Anzeigetext aus Textdatei lesen
; Parameter 1: Dateiname
;-------------------------------------

( DEFUN tdw-read-file (result-file)
    (LET ((string-list nil)
         )

        ( WITH-OPEN-FILE ( my-file result-file :DIRECTION :INPUT)

     (LET (contents )
       (LOOP
        (LET ((text (READ-LINE my-file NIL 'EOF)))

          (IF (EQ text 'EOF)
              (RETURN)
              (PROGN
                ( WHEN Text
                    ( UNLESS ( OR ( STRING= ( SUBSEQ Text 0 1 ) "#" ) ( STRING= ( SUBSEQ Text 0 1 ) ";" ))
                      ( SETF text ( STRING-RIGHT-TRIM '( #\SPACE #\LINEFEED #\RETURN #\NEWLINE ) Text ))
                      ( WHEN Text
                        ( PUSH
                          ( SD-STRING-SPLIT TEXT ";" )
                           string-list ) ;;BM
                      )
                    )
                )
              )
          ) ; End if
        ) ; Ende LET
       ) ; Ende Loop
     ) ; Ende LET contents
    ) ; Ende with-open-file
    string-list
    ) ; Ende LET string-list

) ; Ende Funktion

( DEFUN tdw-get-custom-message ( P_text_row P_vorgabe P_table )
   ( LET (( L_return NIL )
          ( L_cnr ( SD-READ-LOGICAL-TABLE-CELL "tdwsoft-custom-language" :PLIST ( LIST :TDWSOFTNR P_text_row :MODULE P_table ) :COLUMN :CUSTOMNR ))
         )

         ;( WHEN ( FIND-PACKAGE :SCO )
         ; ( SETF L_return ( sco::sco-inq-lola-string L_cnr P_text ))
         ;)

         ; PTC/ CoCreate aufruf einfuegen

         ( UNLESS L_return
           ( SETF L_return P_vorgabe )
         )

      L_return
   )
)

        ( SD-CREATE-LOGICAL-TABLE  "tdwsoft-custom-language"
         :COLUMNS     '( :TDWSOFTNR   :CUSTOMNR    :MODULE    )
         :TYPES       '( :NUMBER :NUMBER :STRING )
         :UNITS       '( NIL NIL NIL )
         :contents  '(
                       (  1 1340 "face-pass-message-table" )
                       (  2 1341 "face-pass-message-table" )
                       (  3 1342 "face-pass-message-table" )
                       (  4 1343 "face-pass-message-table" )
                       (  5 1344 "face-pass-message-table" )
                       (  6 1345 "face-pass-message-table" )
                       (  7 1346 "face-pass-message-table" )
                       (  8 1347 "face-pass-message-table" )
                       (  9 1348 "face-pass-message-table" )
                       ( 10 1349 "face-pass-message-table" )
                       ( 11 1350 "face-pass-message-table" )
                       ( 12 1351 "face-pass-message-table" )
                       ( 13 1352 "face-pass-message-table" )
                       ( 14 1353 "face-pass-message-table" )
                       ( 15 1354 "face-pass-message-table" )
                       ( 16 1355 "face-pass-message-table" )
                       ( 17 1356 "face-pass-message-table" )
                       ( 18 1357 "face-pass-message-table" )
                       ( 19 1358 "face-pass-message-table" )
                       ( 20 1359 "face-pass-message-table" )
                       ( 21 1360 "face-pass-message-table" )
                       ( 22 1361 "face-pass-message-table" )
                       ( 23 1362 "face-pass-message-table" )
                       ( 24 1363 "face-pass-message-table" )
                       ( 25 1364 "face-pass-message-table" )
                       ( 26 1365 "face-pass-message-table" )
                       ( 27 1366 "face-pass-message-table" )
                       ( 28 1367 "face-pass-message-table" )
                       ( 29 1368 "face-pass-message-table" )
                       ( 30 1369 "face-pass-message-table" )
                       ( 31 1370 "face-pass-message-table" )
                       ( 32 1370 "face-pass-message-table" )
                       ( 33 1371 "face-pass-message-table" )
                       ( 34 1372 "face-pass-message-table" )
                      )
        )

( PRINT "tdwsoftenv.lsp loaded")
